@@ -2,6 +2,21 @@ from commonutils import StaticUtils
 from copy import deepcopy
 from .smartwidget import SmartWidget
 
+class SmartWidgetProxy:
+   def __init__(self, smartWidget):
+      self.__value = smartWidget
+   
+   @property
+   def value(self):
+      return self.__value
+   
+   def __getitem__(self, key):
+      return self.__value._baseContainerChildren[key]
+   
+   def __iter__(self):
+      return iter(self.__value._baseContainerChildren.items())
+
+
 class Multiply:
    def __init__(self, child):
       self.__multiply = child.pop("multiply", dict())
@@ -16,7 +31,7 @@ class Multiply:
       indexable = self.__indexables[key]
       
       if not not indexable:
-         child[key] = indexable if "count" not in self.__multiply else indexable[index] if StaticUtils.isIterable(indexable) else f"{indexable}{index + 1 + self.__multiply.get('offsetOfIndexInText', 0)}"
+         child[key] = indexable if "count" not in self.__multiply else indexable[index] if StaticUtils.isIterable(indexable) else "{0}{1}".format(indexable, index + 1 + self.__multiply.get(f"offsetOfIndexIn{key[0].upper()}{key[1:]}", 0))
    
    @property
    def count(self):
@@ -32,29 +47,54 @@ class CommonUIComponents:
    
    @staticmethod
    def inflate(master, config, grid = True):
-      children = CommonUIComponents._inflate(master, config["ui"], StaticUtils.getOrSetIfAbsent(config, "values", []))
+      ui = CommonUIComponents._inflate(master, config["ui"], StaticUtils.getOrSetIfAbsent(config, "values", []))
+      
+      namedChildren = []
       
       from .containers.basecontainer import BaseContainer
       
-      namedChildren = dict()
-      
-      def setNames(child):
-         if child.smartWidgetName != None:
-            namedChildren[child.smartWidgetName] = child
-            
-         if isinstance(child, BaseContainer):
-            for _, ch in child:
-               setNames(ch)
-      
-      for child in children.values():
-         if grid:
-            child.grid()
+      def setNames(path, proxy):
+         isNamed = proxy.value.smartWidgetName != None
          
-         setNames(child)
+         if isNamed:
+            namedChildren.append(((*path, ), proxy))
+         
+         if isinstance(proxy.value, BaseContainer):
+            if isNamed:
+               path.append(proxy.value.smartWidgetName)
+            
+            for p in proxy.value._baseContainerChildren.values():
+               setNames(path, p)
+            
+            if isNamed:
+               path.pop()
       
-      children.update(namedChildren)
+      for proxy in ui.values():
+         if grid:
+            proxy.value.grid()
+         
+         setNames([], proxy)
       
-      return children
+      if CommonUIComponents.DEBUG:
+         print("Registered names: [")
+         
+         for path, proxy in namedChildren:
+            print(path, proxy.value.smartWidgetName, type(proxy.value))
+         
+         print("]")
+      
+      for path, proxy in namedChildren:
+         u = ui
+         
+         for p in path:
+            u = u[p]
+            
+            if type(u) == SmartWidgetProxy:
+               u = u.value._baseContainerChildren
+         
+         u[proxy.value.smartWidgetName] = proxy
+      
+      return ui
    
    @staticmethod
    def init(**params):
@@ -167,7 +207,7 @@ class CommonUIComponents:
             if smartWidget.hasValueBuffer:
                parentBufferIndex += 1
             
-            result[(logicalRow, logicalColumn)] = smartWidget
+            result[(logicalRow, logicalColumn)] = SmartWidgetProxy(smartWidget)
             
             if multiply.lastChildAddsRow and i == multiply.count - 1:
                grid["lastColumn"] = True
