@@ -10,12 +10,15 @@ class Entry(SmartWidget, TtkEntry):
       if "font" not in kw and Entry.__FONT:
          kw["font"] = Entry.__FONT
       
+      value = StringVar()
+      value.set(kw.get("text", ""))
+      
       kw["hasValueBuffer"] = True
-      kw["value"] = kw["textvariable"] = StringVar()
+      kw["value"] = kw["textvariable"] = value
       
       SmartWidget.__init__(self, master, **kw)
       
-      self.value.set(StaticUtils.getOrSetIfAbsent(self._smartWidgetValueBuffer, 0, ""))
+      self.value.set(StaticUtils.getOrSetIfAbsent(self._smartWidgetValueBuffer, 0, self.value.get()))
       
       self.value.trace_add("write", lambda *_: StaticUtils.setSafely(self._smartWidgetValueBuffer, 0, self.value.get()))
    
